@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Andras Mantia <amantia@kde.org>
+    SPDX-FileCopyrightText: 2009 Andras Mantia <amantia@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIMAP_ACLJOBBASE_H
@@ -27,7 +14,6 @@
 
 namespace KIMAP
 {
-
 class Session;
 struct Response;
 class AclJobBasePrivate;
@@ -36,11 +22,11 @@ class AclJobBasePrivate;
  * Base class for jobs that operate on mailbox ACLs
  *
  * Provides support for the IMAP ACL extension, as defined by
- * <a href="http://www.apps.ietf.org/rfc/rfc4314.html" title="IMAP ACL extension">RFC 4314</a>.
+ * <a href="https://tools.ietf.org/html/rfc4314" title="IMAP ACL extension">RFC 4314</a>.
  *
  * This class cannot be used directly, you must subclass it and reimplement
  * at least the doStart() method.
-*/
+ */
 class KIMAP_EXPORT AclJobBase : public Job
 {
     Q_OBJECT
@@ -55,11 +41,7 @@ public:
     /**
      * Used when subclassing to specify how the ACL will be modified.
      */
-    enum AclModifier {
-        Add = 0,
-        Remove,
-        Change
-    };
+    enum AclModifier { Add = 0, Remove, Change };
 
     /**
      * Set the mailbox to act on
@@ -74,7 +56,6 @@ public:
 
 protected:
     explicit AclJobBase(JobPrivate &dd);
-
 };
 
 }
