@@ -10,8 +10,8 @@
 
 #include "imapstreamparser.h"
 
-#include <ctype.h>
 #include <QIODevice>
+#include <ctype.h>
 
 using namespace KIMAP;
 
@@ -66,20 +66,14 @@ bool ImapStreamParser::hasString()
     m_position = savedPos;
     const char dataChar = m_data.at(pos);
     if (dataChar == '{') {
-        return true; //literal string
+        return true; // literal string
     } else if (dataChar == '"') {
-        return true; //quoted string
-    } else if (dataChar != ' ' &&
-            dataChar != '(' &&
-            dataChar != ')' &&
-            dataChar != '[' &&
-            dataChar != ']' &&
-            dataChar != '\n' &&
-            dataChar != '\r') {
-        return true;  //unquoted string
+        return true; // quoted string
+    } else if (dataChar != ' ' && dataChar != '(' && dataChar != ')' && dataChar != '[' && dataChar != ']' && dataChar != '\n' && dataChar != '\r') {
+        return true; // unquoted string
     }
 
-    return false; //something else, not a string
+    return false; // something else, not a string
 }
 
 bool ImapStreamParser::hasLiteral()
@@ -112,7 +106,7 @@ bool ImapStreamParser::hasLiteral()
             ++m_position;
         }
 
-        //FIXME: Makes sense only on the server side?
+        // FIXME: Makes sense only on the server side?
         if (m_isServerModeEnabled && m_literalSize > 0) {
             sendContinuationResponse(m_literalSize);
         }
@@ -137,7 +131,7 @@ QByteArray ImapStreamParser::readLiteralPart()
         throw ImapParserException("Unable to read more data");
     }
 
-    if (m_data.length() < m_position + size) {   // Still not enough data
+    if (m_data.length() < m_position + size) { // Still not enough data
         // Take what's already there
         size = m_data.length() - m_position;
     }
@@ -191,7 +185,7 @@ QList<QByteArray> ImapStreamParser::readParenthesizedList()
 
     stripLeadingSpaces();
     if (m_data.at(m_position) != '(') {
-        return result; //no list found
+        return result; // no list found
     }
 
     bool concatToLast = false;
@@ -199,13 +193,11 @@ QList<QByteArray> ImapStreamParser::readParenthesizedList()
     int sublistbegin = m_position;
     int i = m_position + 1;
     Q_FOREVER {
-    if (!waitForMoreData(m_data.length() <= i))
-        {
+        if (!waitForMoreData(m_data.length() <= i)) {
             m_position = i;
             throw ImapParserException("Unable to read more data");
         }
-        if (m_data.at(i) == '(')
-        {
+        if (m_data.at(i) == '(') {
             ++count;
             if (count == 1) {
                 sublistbegin = i;
@@ -213,8 +205,7 @@ QList<QByteArray> ImapStreamParser::readParenthesizedList()
             ++i;
             continue;
         }
-        if (m_data.at(i) == ')')
-        {
+        if (m_data.at(i) == ')') {
             if (count <= 0) {
                 m_position = i + 1;
                 return result;
@@ -226,13 +217,11 @@ QList<QByteArray> ImapStreamParser::readParenthesizedList()
             ++i;
             continue;
         }
-        if (m_data.at(i) == ' ')
-        {
+        if (m_data.at(i) == ' ') {
             ++i;
             continue;
         }
-        if (m_data.at(i) == '"')
-        {
+        if (m_data.at(i) == '"') {
             if (count > 0) {
                 m_position = i;
                 parseQuotedString();
@@ -240,8 +229,7 @@ QList<QByteArray> ImapStreamParser::readParenthesizedList()
                 continue;
             }
         }
-        if (m_data.at(i) == '[')
-        {
+        if (m_data.at(i) == '[') {
             concatToLast = true;
             if (result.isEmpty()) {
                 result.append(QByteArray());
@@ -250,15 +238,13 @@ QList<QByteArray> ImapStreamParser::readParenthesizedList()
             ++i;
             continue;
         }
-        if (m_data.at(i) == ']')
-        {
+        if (m_data.at(i) == ']') {
             concatToLast = false;
             result.last() += ']';
             ++i;
             continue;
         }
-        if (count == 0)
-        {
+        if (count == 0) {
             m_position = i;
             QByteArray ba;
             if (hasLiteral()) {
@@ -271,8 +257,7 @@ QList<QByteArray> ImapStreamParser::readParenthesizedList()
 
             // We might sometime get some unwanted CRLF, but we're still not at the end
             // of the list, would make further string reads fail so eat the CRLFs.
-            while ((m_position < m_data.size()) &&
-                    (m_data.at(m_position) == '\r' || m_data.at(m_position) == '\n')) {
+            while ((m_position < m_data.size()) && (m_data.at(m_position) == '\r' || m_data.at(m_position) == '\n')) {
                 m_position++;
             }
 
@@ -343,19 +328,16 @@ QByteArray ImapStreamParser::parseQuotedString()
         ++m_position;
         int i = m_position;
         Q_FOREVER {
-        if (!waitForMoreData(m_data.length() <= i))
-            {
+            if (!waitForMoreData(m_data.length() <= i)) {
                 m_position = i;
                 throw ImapParserException("Unable to read more data");
             }
-            if (m_data.at(i) == '\\')
-            {
+            if (m_data.at(i) == '\\') {
                 i += 2;
                 foundSlash = true;
                 continue;
             }
-            if (m_data.at(i) == '"')
-            {
+            if (m_data.at(i) == '"') {
                 result = m_data.mid(m_position, i - m_position);
                 end = i + 1; // skip the '"'
                 break;
@@ -369,31 +351,22 @@ QByteArray ImapStreamParser::parseQuotedString()
         bool reachedInputEnd = true;
         int i = m_position;
         Q_FOREVER {
-        if (!waitForMoreData(m_data.length() <= i))
-            {
+            if (!waitForMoreData(m_data.length() <= i)) {
                 m_position = i;
                 throw ImapParserException("Unable to read more data");
             }
-            if (m_data.at(i) == ' ' ||
-            m_data.at(i) == '(' ||
-            m_data.at(i) == ')' ||
-            m_data.at(i) == '[' ||
-            m_data.at(i) == ']' ||
-            m_data.at(i) == '\n' ||
-            m_data.at(i) == '\r' ||
-            m_data.at(i) == '"')
-            {
+            if (m_data.at(i) == ' ' || m_data.at(i) == '(' || m_data.at(i) == ')' || m_data.at(i) == '[' || m_data.at(i) == ']' || m_data.at(i) == '\n'
+                || m_data.at(i) == '\r' || m_data.at(i) == '"') {
                 end = i;
                 reachedInputEnd = false;
                 break;
             }
-            if (m_data.at(i) == '\\')
-            {
+            if (m_data.at(i) == '\\') {
                 foundSlash = true;
             }
             i++;
         }
-        if (reachedInputEnd) {   //FIXME: how can it get here?
+        if (reachedInputEnd) { // FIXME: how can it get here?
             end = m_data.length();
         }
 
@@ -415,7 +388,7 @@ QByteArray ImapStreamParser::parseQuotedString()
 
 qint64 ImapStreamParser::readNumber(bool *ok)
 {
-    qint64  result;
+    qint64 result;
     if (ok) {
         *ok = false;
     }
@@ -431,13 +404,11 @@ qint64 ImapStreamParser::readNumber(bool *ok)
     }
     int i = m_position;
     Q_FOREVER {
-    if (!waitForMoreData(m_data.length() <= i))
-        {
+        if (!waitForMoreData(m_data.length() <= i)) {
             m_position = i;
             throw ImapParserException("Unable to read more data");
         }
-        if (!isdigit(m_data.at(i)))
-        {
+        if (!isdigit(m_data.at(i))) {
             break;
         }
         ++i;
@@ -462,8 +433,7 @@ void ImapStreamParser::stripLeadingSpaces()
 bool ImapStreamParser::waitForMoreData(bool wait)
 {
     if (wait) {
-        if (m_socket->bytesAvailable() > 0 ||
-                m_socket->waitForReadyRead(30000)) {
+        if (m_socket->bytesAvailable() > 0 || m_socket->waitForReadyRead(30000)) {
             m_data.append(m_socket->readAll());
         } else {
             return false;
@@ -508,10 +478,10 @@ bool ImapStreamParser::atCommandEnd()
         // We'd better empty m_data from time to time before it grows out of control
         trimBuffer();
 
-        return true; //command end
+        return true; // command end
     }
     m_position = savedPos;
-    return false; //something else
+    return false; // something else
 }
 
 QByteArray ImapStreamParser::readUntilCommandEnd()
@@ -520,33 +490,27 @@ QByteArray ImapStreamParser::readUntilCommandEnd()
     int i = m_position;
     int paranthesisBalance = 0;
     Q_FOREVER {
-    if (!waitForMoreData(m_data.length() <= i))
-        {
+        if (!waitForMoreData(m_data.length() <= i)) {
             m_position = i;
             throw ImapParserException("Unable to read more data");
         }
-        if (m_data.at(i) == '{')
-        {
+        if (m_data.at(i) == '{') {
             m_position = i - 1;
-            hasLiteral(); //init literal size
-            result.append( m_data.mid( i, m_position + 1 ) );
+            hasLiteral(); // init literal size
+            result.append(m_data.mid(i, m_position + 1));
             while (!atLiteralEnd()) {
                 result.append(readLiteralPart());
             }
             i = m_position;
         }
-        if (m_data.at(i) == '(')
-        {
+        if (m_data.at(i) == '(') {
             paranthesisBalance++;
         }
-        if (m_data.at(i) == ')')
-        {
+        if (m_data.at(i) == ')') {
             paranthesisBalance--;
         }
-        if ((i == m_data.length() && paranthesisBalance == 0) ||
-                m_data.at(i) == '\n'  || m_data.at(i) == '\r')
-        {
-            break; //command end
+        if ((i == m_data.length() && paranthesisBalance == 0) || m_data.at(i) == '\n' || m_data.at(i) == '\r') {
+            break; // command end
         }
         result.append(m_data.at(i));
         ++i;
@@ -558,15 +522,14 @@ QByteArray ImapStreamParser::readUntilCommandEnd()
 
 void ImapStreamParser::sendContinuationResponse(qint64 size)
 {
-    QByteArray block = "+ Ready for literal data (expecting " +
-                       QByteArray::number(size) + " bytes)\r\n";
+    QByteArray block = "+ Ready for literal data (expecting " + QByteArray::number(size) + " bytes)\r\n";
     m_socket->write(block);
     m_socket->waitForBytesWritten(30000);
 }
 
 void ImapStreamParser::trimBuffer()
 {
-    if (m_position < 4096) {   // right() is expensive, so don't do it for every line
+    if (m_position < 4096) { // right() is expensive, so don't do it for every line
         return;
     }
     m_data = m_data.right(m_data.size() - m_position);
