@@ -9,17 +9,16 @@
 
 #include "kimap_export.h"
 
-#include "job.h"
 #include "imapset.h"
+#include "job.h"
 
 namespace KIMAP
 {
-
 class Session;
 struct Response;
 class StoreJobPrivate;
 
-typedef QList<QByteArray> MessageFlags;
+using MessageFlags = QList<QByteArray>;
 
 class KIMAP_EXPORT StoreJob : public Job
 {
@@ -29,11 +28,7 @@ class KIMAP_EXPORT StoreJob : public Job
     friend class SessionPrivate;
 
 public:
-    enum StoreMode {
-        SetFlags,
-        AppendFlags,
-        RemoveFlags
-    };
+    enum StoreMode { SetFlags, AppendFlags, RemoveFlags };
 
     explicit StoreJob(Session *session);
     ~StoreJob() override;
